---
title: Contributing
slug: '/cloud/contributing'
description: 'Learn how to contribute to Tuist Cloud.'
---

Tuist is an opensource project first and foremost. We are driven by the community and Tuist Cloud is no exception. However, to get both the development and production app running, we rely on a couple of services encrypted with a `master.key` that we can't share with every contributor.

That being said, we still want you to be able to contribute. This guide goes through what you need to do to get set up.

## Getting started

The first thing you'll need to do is to check out tuist if you don't have it locally:
```bash
git clone https://github.com/tuist/tuist
```

And then navigate to the cloud project:
```bash
cd tuist/projects/cloud
```

Once you're in the cloud directory, we recommend switching to the Node and Ruby versions defined in `.nvmrc` and `.ruby-version` files, respectively. We recommend using [nvm](https://github.com/nvm-sh/nvm) and [chruby](https://github.com/postmodern/chruby) to easily switch between given versions. Afterwards, you can run `./up`. This script will install the necessary dependencies, set up a new `master.key` if you don't have one already, and create a new `credentials.yml` file that you will be able to start editing right away.

The file `credentials.yml.enc` showcases what credentials you might need. That being said, you might _not_ need all of them, depending on what you want to do. If you want to post a PR, do _not_ commit this file.

To get you started with some pre-generated accounts, you can run:
```bash
bin/rails db:seed
```

You should see the account names with their passwords – you can use those in the login page.

## Run the dev server

It's time to run our `dev` server 🎉

You can run `./dev` and this will spin up a local instance at http://127.0.0.1:3000. You can navigate from the landing page to the `Login` and use one of the credentials from the `bin/rails db:seed` command to log in. You should now be able to create a new project that will be saved in your local database!

A big part of Tuist Cloud is dependent on the storage for the cache. For this we use AWS – it's highly likely you will need to set up this service for development.

### Tuist CLI

The `tuist` CLI automatically uses remote cache if you have a `Config.swift` similar to this:
```swift
import ProjectDescription

let config = Config(
    cloud: .cloud(projectId: "your-organization/your-project", url: "https://cloud.tuist.io", options: [.optional])
)
```

To use the locally running tuist cloud, you can just change the `url` to http://127.0.0.1:3000 or whatever URL the local Rails app is running on.

### AWS

[AWS](https://aws.amazon.com/) is our current storage of choice. Tuist Cloud receives cached framework from the `tuist` CLI and saves them in AWS – and vice-versa, it serves cached frameworks from the AWS to the `tuist` CLI.

For Tuist Cloud, we need two things: `access_key_id` and `secret_access_key`. Once you sign up to AWS, you can follow [this](https://docs.aws.amazon.com/powershell/latest/userguide/pstools-appendix-sign-up.html) guide to obtain the necessary credentials.

## Authentication

If you want to test out the sign up or Github login flow, you will need to additionally set up credentials for [devise](https://github.com/heartcombo/devise) and [mailgun](https://www.mailgun.com/). This will usually not be necessary for developing Tuist Cloud.

### Devise

[Devise](https://github.com/heartcombo/devise) is an authentication framework we use for both email and GitHub log in.

You can set up a `secret_key` and `pepper` via using secrets generated by `bin/rails secret` – this is not necessary for development purposes. These values are not necessary for development but we recommend changing them if you plan to self-host Tuist Cloud.

If you want to work with the social GitHub login, you will need to set up Omniauth. For that, it is necessary to create a new GitHub app in your Developer settings and follow the guide [here](https://docs.github.com/en/developers/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps) to obtain the necessary keys.

### Mailgun

We use [Mailgun](https://www.mailgun.com/) to send email confirmation during email sign up. Once you sign up, you can follow this [guide](https://documentation.mailgun.com/en/latest/quickstart-sending.html#how-to-start-sending-email) to get credentials for sending emails via SMTP. In the credentials files, you will use the appropriate values in `smpt_settings`.